Xgit v0.3.0 Xgit.Core.Tree.Entry View Source
A single file in a tree structure.
Link to this section Summary
Functions
Compare two entries according to git file name sorting rules.
Return true if this entry struct describes a valid tree entry.
Link to this section Types
Link to this type
t()
View Sourcet() :: %Xgit.Core.Tree.Entry{
mode: Xgit.Core.FileMode.t(),
name: Xgit.Core.FilePath.t(),
object_id: Xgit.Core.ObjectId.t()
}
A single file in a tree structure.
Struct Members
name: (FilePath.t) entry path name, relative to top-level directory (without leading slash)object_id: (ObjectId.t) SHA-1 for the represented objectmode: (FileMode.t)
Link to this section Functions
Compare two entries according to git file name sorting rules.
Return Value
:ltifentry1sorts beforeentry2.:eqif they are the same.:gtifentry1sorts afterentry2.
Return true if this entry struct describes a valid tree entry.